@@ -25,7 +25,7 @@ class FlashCardBackendMode : public AbstractBackendMode
     Q_OBJECT
 
 public:
-    FlashCardBackendMode(const PracticeOptions& PracticeOptions, AbstractFrontend *frontend, QObject *parent);
+    FlashCardBackendMode(AbstractFrontend *frontend, QObject *parent);
     virtual bool setTestEntry(TestEntry* current);
 
 public Q_SLOTS:
